---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

I have:
- [ ] searched open and closed issues for duplicates
- [ ] opened a discussion and received the approval from a maintainer to file an issue

Also:
- [ ] this is not a feature request (go to Discussions)

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
- add your steps here
- as a list
- using hyphens

**Expected behavior**
A clear and concise description of what you expected to happen.

**Device**
Manufacturer Model Revision

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Software (please complete the following information):**
- OS with version
- `escp` version
- python version
